@@ -31,22 +31,22 @@ def cartesian_product(listoflists):
     return res
 
 
-def arrayed_identifiers(expression, dimension):
+def arrayed_identifiers(expression, dimension, entity, dimensions):
     dim =str(dimension).replace("'","").replace("(","").replace(")","").replace(" ","")
     if type(expression) is int or type(expression) is str or type(expression) is float:
         return expression
 
     if type(expression) is list:
-        return [arrayed_identifiers(x,dimension) for x in expression]
+        return [arrayed_identifiers(x,dimension,entity, dimensions) for x in expression]
 
     if "args" in expression.keys():
         args = []
         for arg in expression["args"]:
-            args+= [arrayed_identifiers(arg, dimension)]
+            args+= [arrayed_identifiers(arg, dimension, entity, dimensions)]
 
         expression["args"] = args
 
-    if expression["type"] == "identifier":
+    if expression["type"] == "identifier" and all([expression["name"] in [variable["name"] for variable in dimensions[dimension]["variables"]] for dimension in entity["dimensions"]]):
         expression["name"] = expression["name"] + "[{}]".format(dim)
 
     return expression
@@ -196,7 +196,7 @@ def spread_function_arguments(expression, model_name, IR):
     return expression
 
 
-def clone_entity(model_name, entity, idx, product=None, connects=None,dimensions={}):
+def clone_entity(model_name, entity, idx, product=None, connects=None,dimensions={},entities=None):
     ent = deepcopy(entity)
     try:
         from ..parsers.smile.grammar import SMILEVisitor, grammar
@@ -235,8 +235,7 @@ def clone_entity(model_name, entity, idx, product=None, connects=None,dimensions
         ent["equation_parsed"] = replaceDimensionNames(ent["equation_parsed"], ent, dimensions)
 
         # Array all identifiers
-        ent["equation_parsed"] = arrayed_identifiers(ent["equation_parsed"], dimension=product)
-
+        ent["equation_parsed"] = arrayed_identifiers(ent["equation_parsed"], dimension=product,entity=entity,dimensions=dimensions)
 
         # Build equation from inflows and outflows
         if (not inflows["type"] == "nothing") and (outflows["type"] == "nothing"):  # Only inflows
@@ -304,6 +303,7 @@ def ExpandArrays(IR):
     :param IR:
     :return:
     """
+
     for name, model in IR["models"].items():
         '''
         Traverse the IR
@@ -317,6 +317,7 @@ def ExpandArrays(IR):
 
                 _entities = []
 
+                #TODO investigate this
                 try:
                     if type(entity["equation_parsed"]) is list and type(entity["equation_parsed"][0]) is dict and entity["equation_parsed"][0]["name"] == "size":
                         continue
@@ -398,8 +399,7 @@ def ExpandArrays(IR):
 
                     entities[index]["equation_parsed"] = already_reduced
 
-                spread_function_arguments(expression=model["entities"][entity_type][index]["equation_parsed"],
-                model_name=model["name"], IR=IR)
+                spread_function_arguments(expression=model["entities"][entity_type][index]["equation_parsed"], model_name=model["name"], IR=IR)
                 entities[index]["labels"] = []
                 model["entities"][entity_type] += _entities
 
